# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateProduct(BaseModel):
    create_product: Optional["CreateProductCreateProduct"] = Field(
        alias="createProduct"
    )


class CreateProductCreateProduct(BaseModel):
    id: str
    name: str


CreateProduct.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentSourceTypes


class RetrieveView(BaseModel):
    retrieve_view: Optional["RetrieveViewRetrieveView"] = Field(alias="retrieveView")


class RetrieveViewRetrieveView(BaseModel):
    results: Optional[List[Optional["RetrieveViewRetrieveViewResults"]]]


class RetrieveViewRetrieveViewResults(BaseModel):
    type: Optional[ContentSourceTypes]
    content: "RetrieveViewRetrieveViewResultsContent"
    text: str
    metadata: Optional[str]
    relevance: float
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    frame_number: Optional[int] = Field(alias="frameNumber")


class RetrieveViewRetrieveViewResultsContent(BaseModel):
    id: str


RetrieveView.model_rebuild()
RetrieveViewRetrieveView.model_rebuild()
RetrieveViewRetrieveViewResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentTypes, EntityState, FileTypes, ObservableTypes, ViewTypes


class QueryViews(BaseModel):
    views: Optional["QueryViewsViews"]


class QueryViewsViews(BaseModel):
    results: Optional[List["QueryViewsViewsResults"]]


class QueryViewsViewsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "QueryViewsViewsResultsOwner"
    state: EntityState
    type: Optional[ViewTypes]
    filter: Optional["QueryViewsViewsResultsFilter"]
    augmented_filter: Optional["QueryViewsViewsResultsAugmentedFilter"] = Field(
        alias="augmentedFilter"
    )


class QueryViewsViewsResultsOwner(BaseModel):
    id: str


class QueryViewsViewsResultsFilter(BaseModel):
    date_range: Optional["QueryViewsViewsResultsFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional["QueryViewsViewsResultsFilterCreationDateRange"] = (
        Field(alias="creationDateRange")
    )
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["QueryViewsViewsResultsFilterFileSizeRange"] = Field(
        alias="fileSizeRange"
    )
    similar_contents: Optional[List["QueryViewsViewsResultsFilterSimilarContents"]] = (
        Field(alias="similarContents")
    )
    contents: Optional[List["QueryViewsViewsResultsFilterContents"]]
    feeds: Optional[List["QueryViewsViewsResultsFilterFeeds"]]
    workflows: Optional[List["QueryViewsViewsResultsFilterWorkflows"]]
    collections: Optional[List["QueryViewsViewsResultsFilterCollections"]]
    users: Optional[List["QueryViewsViewsResultsFilterUsers"]]
    observations: Optional[List["QueryViewsViewsResultsFilterObservations"]]
    or_: Optional[List["QueryViewsViewsResultsFilterOr"]] = Field(alias="or")
    and_: Optional[List["QueryViewsViewsResultsFilterAnd"]] = Field(alias="and")


class QueryViewsViewsResultsFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryViewsViewsResultsFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryViewsViewsResultsFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryViewsViewsResultsFilterSimilarContents(BaseModel):
    id: str


class QueryViewsViewsResultsFilterContents(BaseModel):
    id: str


class QueryViewsViewsResultsFilterFeeds(BaseModel):
    id: str


class QueryViewsViewsResultsFilterWorkflows(BaseModel):
    id: str


class QueryViewsViewsResultsFilterCollections(BaseModel):
    id: str


class QueryViewsViewsResultsFilterUsers(BaseModel):
    id: str


class QueryViewsViewsResultsFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryViewsViewsResultsFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryViewsViewsResultsFilterObservationsObservable(BaseModel):
    id: str


class QueryViewsViewsResultsFilterOr(BaseModel):
    feeds: Optional[List["QueryViewsViewsResultsFilterOrFeeds"]]
    workflows: Optional[List["QueryViewsViewsResultsFilterOrWorkflows"]]
    collections: Optional[List["QueryViewsViewsResultsFilterOrCollections"]]
    users: Optional[List["QueryViewsViewsResultsFilterOrUsers"]]
    observations: Optional[List["QueryViewsViewsResultsFilterOrObservations"]]


class QueryViewsViewsResultsFilterOrFeeds(BaseModel):
    id: str


class QueryViewsViewsResultsFilterOrWorkflows(BaseModel):
    id: str


class QueryViewsViewsResultsFilterOrCollections(BaseModel):
    id: str


class QueryViewsViewsResultsFilterOrUsers(BaseModel):
    id: str


class QueryViewsViewsResultsFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryViewsViewsResultsFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryViewsViewsResultsFilterOrObservationsObservable(BaseModel):
    id: str


class QueryViewsViewsResultsFilterAnd(BaseModel):
    feeds: Optional[List["QueryViewsViewsResultsFilterAndFeeds"]]
    workflows: Optional[List["QueryViewsViewsResultsFilterAndWorkflows"]]
    collections: Optional[List["QueryViewsViewsResultsFilterAndCollections"]]
    users: Optional[List["QueryViewsViewsResultsFilterAndUsers"]]
    observations: Optional[List["QueryViewsViewsResultsFilterAndObservations"]]


class QueryViewsViewsResultsFilterAndFeeds(BaseModel):
    id: str


class QueryViewsViewsResultsFilterAndWorkflows(BaseModel):
    id: str


class QueryViewsViewsResultsFilterAndCollections(BaseModel):
    id: str


class QueryViewsViewsResultsFilterAndUsers(BaseModel):
    id: str


class QueryViewsViewsResultsFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryViewsViewsResultsFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryViewsViewsResultsFilterAndObservationsObservable(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilter(BaseModel):
    date_range: Optional["QueryViewsViewsResultsAugmentedFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional[
        "QueryViewsViewsResultsAugmentedFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["QueryViewsViewsResultsAugmentedFilterFileSizeRange"] = (
        Field(alias="fileSizeRange")
    )
    similar_contents: Optional[
        List["QueryViewsViewsResultsAugmentedFilterSimilarContents"]
    ] = Field(alias="similarContents")
    contents: Optional[List["QueryViewsViewsResultsAugmentedFilterContents"]]
    feeds: Optional[List["QueryViewsViewsResultsAugmentedFilterFeeds"]]
    workflows: Optional[List["QueryViewsViewsResultsAugmentedFilterWorkflows"]]
    collections: Optional[List["QueryViewsViewsResultsAugmentedFilterCollections"]]
    users: Optional[List["QueryViewsViewsResultsAugmentedFilterUsers"]]
    observations: Optional[List["QueryViewsViewsResultsAugmentedFilterObservations"]]
    or_: Optional[List["QueryViewsViewsResultsAugmentedFilterOr"]] = Field(alias="or")
    and_: Optional[List["QueryViewsViewsResultsAugmentedFilterAnd"]] = Field(
        alias="and"
    )


class QueryViewsViewsResultsAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryViewsViewsResultsAugmentedFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryViewsViewsResultsAugmentedFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryViewsViewsResultsAugmentedFilterSimilarContents(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterContents(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterFeeds(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterWorkflows(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterCollections(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterUsers(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryViewsViewsResultsAugmentedFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryViewsViewsResultsAugmentedFilterObservationsObservable(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterOr(BaseModel):
    feeds: Optional[List["QueryViewsViewsResultsAugmentedFilterOrFeeds"]]
    workflows: Optional[List["QueryViewsViewsResultsAugmentedFilterOrWorkflows"]]
    collections: Optional[List["QueryViewsViewsResultsAugmentedFilterOrCollections"]]
    users: Optional[List["QueryViewsViewsResultsAugmentedFilterOrUsers"]]
    observations: Optional[List["QueryViewsViewsResultsAugmentedFilterOrObservations"]]


class QueryViewsViewsResultsAugmentedFilterOrFeeds(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterOrWorkflows(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterOrCollections(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterOrUsers(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryViewsViewsResultsAugmentedFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryViewsViewsResultsAugmentedFilterOrObservationsObservable(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterAnd(BaseModel):
    feeds: Optional[List["QueryViewsViewsResultsAugmentedFilterAndFeeds"]]
    workflows: Optional[List["QueryViewsViewsResultsAugmentedFilterAndWorkflows"]]
    collections: Optional[List["QueryViewsViewsResultsAugmentedFilterAndCollections"]]
    users: Optional[List["QueryViewsViewsResultsAugmentedFilterAndUsers"]]
    observations: Optional[List["QueryViewsViewsResultsAugmentedFilterAndObservations"]]


class QueryViewsViewsResultsAugmentedFilterAndFeeds(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterAndWorkflows(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterAndCollections(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterAndUsers(BaseModel):
    id: str


class QueryViewsViewsResultsAugmentedFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryViewsViewsResultsAugmentedFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class QueryViewsViewsResultsAugmentedFilterAndObservationsObservable(BaseModel):
    id: str


QueryViews.model_rebuild()
QueryViewsViews.model_rebuild()
QueryViewsViewsResults.model_rebuild()
QueryViewsViewsResultsFilter.model_rebuild()
QueryViewsViewsResultsFilterObservations.model_rebuild()
QueryViewsViewsResultsFilterOr.model_rebuild()
QueryViewsViewsResultsFilterOrObservations.model_rebuild()
QueryViewsViewsResultsFilterAnd.model_rebuild()
QueryViewsViewsResultsFilterAndObservations.model_rebuild()
QueryViewsViewsResultsAugmentedFilter.model_rebuild()
QueryViewsViewsResultsAugmentedFilterObservations.model_rebuild()
QueryViewsViewsResultsAugmentedFilterOr.model_rebuild()
QueryViewsViewsResultsAugmentedFilterOrObservations.model_rebuild()
QueryViewsViewsResultsAugmentedFilterAnd.model_rebuild()
QueryViewsViewsResultsAugmentedFilterAndObservations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteView(BaseModel):
    delete_view: Optional["DeleteViewDeleteView"] = Field(alias="deleteView")


class DeleteViewDeleteView(BaseModel):
    id: str
    state: EntityState


DeleteView.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentTypes, EntityState, FileTypes, ObservableTypes, ViewTypes


class CreateView(BaseModel):
    create_view: Optional["CreateViewCreateView"] = Field(alias="createView")


class CreateViewCreateView(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ViewTypes]
    filter: Optional["CreateViewCreateViewFilter"]
    augmented_filter: Optional["CreateViewCreateViewAugmentedFilter"] = Field(
        alias="augmentedFilter"
    )


class CreateViewCreateViewFilter(BaseModel):
    date_range: Optional["CreateViewCreateViewFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional["CreateViewCreateViewFilterCreationDateRange"] = (
        Field(alias="creationDateRange")
    )
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["CreateViewCreateViewFilterFileSizeRange"] = Field(
        alias="fileSizeRange"
    )
    similar_contents: Optional[List["CreateViewCreateViewFilterSimilarContents"]] = (
        Field(alias="similarContents")
    )
    contents: Optional[List["CreateViewCreateViewFilterContents"]]
    feeds: Optional[List["CreateViewCreateViewFilterFeeds"]]
    workflows: Optional[List["CreateViewCreateViewFilterWorkflows"]]
    collections: Optional[List["CreateViewCreateViewFilterCollections"]]
    users: Optional[List["CreateViewCreateViewFilterUsers"]]
    observations: Optional[List["CreateViewCreateViewFilterObservations"]]
    or_: Optional[List["CreateViewCreateViewFilterOr"]] = Field(alias="or")
    and_: Optional[List["CreateViewCreateViewFilterAnd"]] = Field(alias="and")


class CreateViewCreateViewFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewFilterSimilarContents(BaseModel):
    id: str


class CreateViewCreateViewFilterContents(BaseModel):
    id: str


class CreateViewCreateViewFilterFeeds(BaseModel):
    id: str


class CreateViewCreateViewFilterWorkflows(BaseModel):
    id: str


class CreateViewCreateViewFilterCollections(BaseModel):
    id: str


class CreateViewCreateViewFilterUsers(BaseModel):
    id: str


class CreateViewCreateViewFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class CreateViewCreateViewFilterObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewFilterOr(BaseModel):
    feeds: Optional[List["CreateViewCreateViewFilterOrFeeds"]]
    workflows: Optional[List["CreateViewCreateViewFilterOrWorkflows"]]
    collections: Optional[List["CreateViewCreateViewFilterOrCollections"]]
    users: Optional[List["CreateViewCreateViewFilterOrUsers"]]
    observations: Optional[List["CreateViewCreateViewFilterOrObservations"]]


class CreateViewCreateViewFilterOrFeeds(BaseModel):
    id: str


class CreateViewCreateViewFilterOrWorkflows(BaseModel):
    id: str


class CreateViewCreateViewFilterOrCollections(BaseModel):
    id: str


class CreateViewCreateViewFilterOrUsers(BaseModel):
    id: str


class CreateViewCreateViewFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class CreateViewCreateViewFilterOrObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewFilterAnd(BaseModel):
    feeds: Optional[List["CreateViewCreateViewFilterAndFeeds"]]
    workflows: Optional[List["CreateViewCreateViewFilterAndWorkflows"]]
    collections: Optional[List["CreateViewCreateViewFilterAndCollections"]]
    users: Optional[List["CreateViewCreateViewFilterAndUsers"]]
    observations: Optional[List["CreateViewCreateViewFilterAndObservations"]]


class CreateViewCreateViewFilterAndFeeds(BaseModel):
    id: str


class CreateViewCreateViewFilterAndWorkflows(BaseModel):
    id: str


class CreateViewCreateViewFilterAndCollections(BaseModel):
    id: str


class CreateViewCreateViewFilterAndUsers(BaseModel):
    id: str


class CreateViewCreateViewFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class CreateViewCreateViewFilterAndObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilter(BaseModel):
    date_range: Optional["CreateViewCreateViewAugmentedFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional[
        "CreateViewCreateViewAugmentedFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["CreateViewCreateViewAugmentedFilterFileSizeRange"] = (
        Field(alias="fileSizeRange")
    )
    similar_contents: Optional[
        List["CreateViewCreateViewAugmentedFilterSimilarContents"]
    ] = Field(alias="similarContents")
    contents: Optional[List["CreateViewCreateViewAugmentedFilterContents"]]
    feeds: Optional[List["CreateViewCreateViewAugmentedFilterFeeds"]]
    workflows: Optional[List["CreateViewCreateViewAugmentedFilterWorkflows"]]
    collections: Optional[List["CreateViewCreateViewAugmentedFilterCollections"]]
    users: Optional[List["CreateViewCreateViewAugmentedFilterUsers"]]
    observations: Optional[List["CreateViewCreateViewAugmentedFilterObservations"]]
    or_: Optional[List["CreateViewCreateViewAugmentedFilterOr"]] = Field(alias="or")
    and_: Optional[List["CreateViewCreateViewAugmentedFilterAnd"]] = Field(alias="and")


class CreateViewCreateViewAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewAugmentedFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewAugmentedFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class CreateViewCreateViewAugmentedFilterSimilarContents(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterContents(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterFeeds(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterWorkflows(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterCollections(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterUsers(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewAugmentedFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class CreateViewCreateViewAugmentedFilterObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOr(BaseModel):
    feeds: Optional[List["CreateViewCreateViewAugmentedFilterOrFeeds"]]
    workflows: Optional[List["CreateViewCreateViewAugmentedFilterOrWorkflows"]]
    collections: Optional[List["CreateViewCreateViewAugmentedFilterOrCollections"]]
    users: Optional[List["CreateViewCreateViewAugmentedFilterOrUsers"]]
    observations: Optional[List["CreateViewCreateViewAugmentedFilterOrObservations"]]


class CreateViewCreateViewAugmentedFilterOrFeeds(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOrWorkflows(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOrCollections(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOrUsers(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewAugmentedFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class CreateViewCreateViewAugmentedFilterOrObservationsObservable(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAnd(BaseModel):
    feeds: Optional[List["CreateViewCreateViewAugmentedFilterAndFeeds"]]
    workflows: Optional[List["CreateViewCreateViewAugmentedFilterAndWorkflows"]]
    collections: Optional[List["CreateViewCreateViewAugmentedFilterAndCollections"]]
    users: Optional[List["CreateViewCreateViewAugmentedFilterAndUsers"]]
    observations: Optional[List["CreateViewCreateViewAugmentedFilterAndObservations"]]


class CreateViewCreateViewAugmentedFilterAndFeeds(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAndWorkflows(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAndCollections(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAndUsers(BaseModel):
    id: str


class CreateViewCreateViewAugmentedFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateViewCreateViewAugmentedFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class CreateViewCreateViewAugmentedFilterAndObservationsObservable(BaseModel):
    id: str


CreateView.model_rebuild()
CreateViewCreateView.model_rebuild()
CreateViewCreateViewFilter.model_rebuild()
CreateViewCreateViewFilterObservations.model_rebuild()
CreateViewCreateViewFilterOr.model_rebuild()
CreateViewCreateViewFilterOrObservations.model_rebuild()
CreateViewCreateViewFilterAnd.model_rebuild()
CreateViewCreateViewFilterAndObservations.model_rebuild()
CreateViewCreateViewAugmentedFilter.model_rebuild()
CreateViewCreateViewAugmentedFilterObservations.model_rebuild()
CreateViewCreateViewAugmentedFilterOr.model_rebuild()
CreateViewCreateViewAugmentedFilterOrObservations.model_rebuild()
CreateViewCreateViewAugmentedFilterAnd.model_rebuild()
CreateViewCreateViewAugmentedFilterAndObservations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentTypes, EntityState, FileTypes, ObservableTypes, ViewTypes


class UpdateView(BaseModel):
    update_view: Optional["UpdateViewUpdateView"] = Field(alias="updateView")


class UpdateViewUpdateView(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ViewTypes]
    filter: Optional["UpdateViewUpdateViewFilter"]
    augmented_filter: Optional["UpdateViewUpdateViewAugmentedFilter"] = Field(
        alias="augmentedFilter"
    )


class UpdateViewUpdateViewFilter(BaseModel):
    date_range: Optional["UpdateViewUpdateViewFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional["UpdateViewUpdateViewFilterCreationDateRange"] = (
        Field(alias="creationDateRange")
    )
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["UpdateViewUpdateViewFilterFileSizeRange"] = Field(
        alias="fileSizeRange"
    )
    similar_contents: Optional[List["UpdateViewUpdateViewFilterSimilarContents"]] = (
        Field(alias="similarContents")
    )
    contents: Optional[List["UpdateViewUpdateViewFilterContents"]]
    feeds: Optional[List["UpdateViewUpdateViewFilterFeeds"]]
    workflows: Optional[List["UpdateViewUpdateViewFilterWorkflows"]]
    collections: Optional[List["UpdateViewUpdateViewFilterCollections"]]
    users: Optional[List["UpdateViewUpdateViewFilterUsers"]]
    observations: Optional[List["UpdateViewUpdateViewFilterObservations"]]
    or_: Optional[List["UpdateViewUpdateViewFilterOr"]] = Field(alias="or")
    and_: Optional[List["UpdateViewUpdateViewFilterAnd"]] = Field(alias="and")


class UpdateViewUpdateViewFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpdateViewUpdateViewFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpdateViewUpdateViewFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpdateViewUpdateViewFilterSimilarContents(BaseModel):
    id: str


class UpdateViewUpdateViewFilterContents(BaseModel):
    id: str


class UpdateViewUpdateViewFilterFeeds(BaseModel):
    id: str


class UpdateViewUpdateViewFilterWorkflows(BaseModel):
    id: str


class UpdateViewUpdateViewFilterCollections(BaseModel):
    id: str


class UpdateViewUpdateViewFilterUsers(BaseModel):
    id: str


class UpdateViewUpdateViewFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "UpdateViewUpdateViewFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class UpdateViewUpdateViewFilterObservationsObservable(BaseModel):
    id: str


class UpdateViewUpdateViewFilterOr(BaseModel):
    feeds: Optional[List["UpdateViewUpdateViewFilterOrFeeds"]]
    workflows: Optional[List["UpdateViewUpdateViewFilterOrWorkflows"]]
    collections: Optional[List["UpdateViewUpdateViewFilterOrCollections"]]
    users: Optional[List["UpdateViewUpdateViewFilterOrUsers"]]
    observations: Optional[List["UpdateViewUpdateViewFilterOrObservations"]]


class UpdateViewUpdateViewFilterOrFeeds(BaseModel):
    id: str


class UpdateViewUpdateViewFilterOrWorkflows(BaseModel):
    id: str


class UpdateViewUpdateViewFilterOrCollections(BaseModel):
    id: str


class UpdateViewUpdateViewFilterOrUsers(BaseModel):
    id: str


class UpdateViewUpdateViewFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "UpdateViewUpdateViewFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class UpdateViewUpdateViewFilterOrObservationsObservable(BaseModel):
    id: str


class UpdateViewUpdateViewFilterAnd(BaseModel):
    feeds: Optional[List["UpdateViewUpdateViewFilterAndFeeds"]]
    workflows: Optional[List["UpdateViewUpdateViewFilterAndWorkflows"]]
    collections: Optional[List["UpdateViewUpdateViewFilterAndCollections"]]
    users: Optional[List["UpdateViewUpdateViewFilterAndUsers"]]
    observations: Optional[List["UpdateViewUpdateViewFilterAndObservations"]]


class UpdateViewUpdateViewFilterAndFeeds(BaseModel):
    id: str


class UpdateViewUpdateViewFilterAndWorkflows(BaseModel):
    id: str


class UpdateViewUpdateViewFilterAndCollections(BaseModel):
    id: str


class UpdateViewUpdateViewFilterAndUsers(BaseModel):
    id: str


class UpdateViewUpdateViewFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "UpdateViewUpdateViewFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class UpdateViewUpdateViewFilterAndObservationsObservable(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilter(BaseModel):
    date_range: Optional["UpdateViewUpdateViewAugmentedFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional[
        "UpdateViewUpdateViewAugmentedFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["UpdateViewUpdateViewAugmentedFilterFileSizeRange"] = (
        Field(alias="fileSizeRange")
    )
    similar_contents: Optional[
        List["UpdateViewUpdateViewAugmentedFilterSimilarContents"]
    ] = Field(alias="similarContents")
    contents: Optional[List["UpdateViewUpdateViewAugmentedFilterContents"]]
    feeds: Optional[List["UpdateViewUpdateViewAugmentedFilterFeeds"]]
    workflows: Optional[List["UpdateViewUpdateViewAugmentedFilterWorkflows"]]
    collections: Optional[List["UpdateViewUpdateViewAugmentedFilterCollections"]]
    users: Optional[List["UpdateViewUpdateViewAugmentedFilterUsers"]]
    observations: Optional[List["UpdateViewUpdateViewAugmentedFilterObservations"]]
    or_: Optional[List["UpdateViewUpdateViewAugmentedFilterOr"]] = Field(alias="or")
    and_: Optional[List["UpdateViewUpdateViewAugmentedFilterAnd"]] = Field(alias="and")


class UpdateViewUpdateViewAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpdateViewUpdateViewAugmentedFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpdateViewUpdateViewAugmentedFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class UpdateViewUpdateViewAugmentedFilterSimilarContents(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterContents(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterFeeds(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterWorkflows(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterCollections(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterUsers(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "UpdateViewUpdateViewAugmentedFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class UpdateViewUpdateViewAugmentedFilterObservationsObservable(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterOr(BaseModel):
    feeds: Optional[List["UpdateViewUpdateViewAugmentedFilterOrFeeds"]]
    workflows: Optional[List["UpdateViewUpdateViewAugmentedFilterOrWorkflows"]]
    collections: Optional[List["UpdateViewUpdateViewAugmentedFilterOrCollections"]]
    users: Optional[List["UpdateViewUpdateViewAugmentedFilterOrUsers"]]
    observations: Optional[List["UpdateViewUpdateViewAugmentedFilterOrObservations"]]


class UpdateViewUpdateViewAugmentedFilterOrFeeds(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterOrWorkflows(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterOrCollections(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterOrUsers(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "UpdateViewUpdateViewAugmentedFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class UpdateViewUpdateViewAugmentedFilterOrObservationsObservable(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterAnd(BaseModel):
    feeds: Optional[List["UpdateViewUpdateViewAugmentedFilterAndFeeds"]]
    workflows: Optional[List["UpdateViewUpdateViewAugmentedFilterAndWorkflows"]]
    collections: Optional[List["UpdateViewUpdateViewAugmentedFilterAndCollections"]]
    users: Optional[List["UpdateViewUpdateViewAugmentedFilterAndUsers"]]
    observations: Optional[List["UpdateViewUpdateViewAugmentedFilterAndObservations"]]


class UpdateViewUpdateViewAugmentedFilterAndFeeds(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterAndWorkflows(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterAndCollections(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterAndUsers(BaseModel):
    id: str


class UpdateViewUpdateViewAugmentedFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "UpdateViewUpdateViewAugmentedFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class UpdateViewUpdateViewAugmentedFilterAndObservationsObservable(BaseModel):
    id: str


UpdateView.model_rebuild()
UpdateViewUpdateView.model_rebuild()
UpdateViewUpdateViewFilter.model_rebuild()
UpdateViewUpdateViewFilterObservations.model_rebuild()
UpdateViewUpdateViewFilterOr.model_rebuild()
UpdateViewUpdateViewFilterOrObservations.model_rebuild()
UpdateViewUpdateViewFilterAnd.model_rebuild()
UpdateViewUpdateViewFilterAndObservations.model_rebuild()
UpdateViewUpdateViewAugmentedFilter.model_rebuild()
UpdateViewUpdateViewAugmentedFilterObservations.model_rebuild()
UpdateViewUpdateViewAugmentedFilterOr.model_rebuild()
UpdateViewUpdateViewAugmentedFilterOrObservations.model_rebuild()
UpdateViewUpdateViewAugmentedFilterAnd.model_rebuild()
UpdateViewUpdateViewAugmentedFilterAndObservations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateCategory(BaseModel):
    create_category: Optional["CreateCategoryCreateCategory"] = Field(
        alias="createCategory"
    )


class CreateCategoryCreateCategory(BaseModel):
    id: str
    name: str


CreateCategory.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalProcedures(BaseModel):
    count_medical_procedures: Optional[
        "CountMedicalProceduresCountMedicalProcedures"
    ] = Field(alias="countMedicalProcedures")


class CountMedicalProceduresCountMedicalProcedures(BaseModel):
    count: Optional[Any]


CountMedicalProcedures.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AssemblyAIModels,
    AzureDocumentIntelligenceModels,
    AzureDocumentIntelligenceVersions,
    ContentClassificationServiceTypes,
    ContentIndexingServiceTypes,
    ContentTypes,
    DeepgramModels,
    EntityEnrichmentServiceTypes,
    EntityExtractionServiceTypes,
    EntityState,
    FilePreparationServiceTypes,
    FileTypes,
    IntegrationServiceTypes,
    LinkTypes,
    MCPServerTypes,
    ObservableTypes,
    ReductoEnrichmentModes,
    ReductoExtractionModes,
    ReductoOcrModes,
    ReductoOcrSystems,
    RegexSourceTypes,
    StoragePolicyTypes,
    SummarizationTypes,
)


class CreateWorkflow(BaseModel):
    create_workflow: Optional["CreateWorkflowCreateWorkflow"] = Field(
        alias="createWorkflow"
    )


class CreateWorkflowCreateWorkflow(BaseModel):
    id: str
    name: str
    state: EntityState
    ingestion: Optional["CreateWorkflowCreateWorkflowIngestion"]
    indexing: Optional["CreateWorkflowCreateWorkflowIndexing"]
    preparation: Optional["CreateWorkflowCreateWorkflowPreparation"]
    extraction: Optional["CreateWorkflowCreateWorkflowExtraction"]
    classification: Optional["CreateWorkflowCreateWorkflowClassification"]
    enrichment: Optional["CreateWorkflowCreateWorkflowEnrichment"]
    storage: Optional["CreateWorkflowCreateWorkflowStorage"]
    actions: Optional[List[Optional["CreateWorkflowCreateWorkflowActions"]]]


class CreateWorkflowCreateWorkflowIngestion(BaseModel):
    if_: Optional["CreateWorkflowCreateWorkflowIngestionIf"] = Field(alias="if")
    collections: Optional[
        List[Optional["CreateWorkflowCreateWorkflowIngestionCollections"]]
    ]
    observations: Optional[
        List[Optional["CreateWorkflowCreateWorkflowIngestionObservations"]]
    ]
    enable_email_collections: Optional[bool] = Field(alias="enableEmailCollections")


class CreateWorkflowCreateWorkflowIngestionIf(BaseModel):
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")


class CreateWorkflowCreateWorkflowIngestionCollections(BaseModel):
    id: str


class CreateWorkflowCreateWorkflowIngestionObservations(BaseModel):
    type: ObservableTypes
    observable: "CreateWorkflowCreateWorkflowIngestionObservationsObservable"


class CreateWorkflowCreateWorkflowIngestionObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class CreateWorkflowCreateWorkflowIndexing(BaseModel):
    jobs: Optional[List[Optional["CreateWorkflowCreateWorkflowIndexingJobs"]]]


class CreateWorkflowCreateWorkflowIndexingJobs(BaseModel):
    connector: Optional["CreateWorkflowCreateWorkflowIndexingJobsConnector"]


class CreateWorkflowCreateWorkflowIndexingJobsConnector(BaseModel):
    type: Optional[ContentIndexingServiceTypes]
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")


class CreateWorkflowCreateWorkflowPreparation(BaseModel):
    enable_unblocked_capture: Optional[bool] = Field(alias="enableUnblockedCapture")
    disable_smart_capture: Optional[bool] = Field(alias="disableSmartCapture")
    summarizations: Optional[
        List[Optional["CreateWorkflowCreateWorkflowPreparationSummarizations"]]
    ]
    jobs: Optional[List[Optional["CreateWorkflowCreateWorkflowPreparationJobs"]]]


class CreateWorkflowCreateWorkflowPreparationSummarizations(BaseModel):
    type: SummarizationTypes
    specification: Optional[
        "CreateWorkflowCreateWorkflowPreparationSummarizationsSpecification"
    ]
    tokens: Optional[int]
    items: Optional[int]
    prompt: Optional[str]


class CreateWorkflowCreateWorkflowPreparationSummarizationsSpecification(BaseModel):
    id: str


class CreateWorkflowCreateWorkflowPreparationJobs(BaseModel):
    connector: Optional["CreateWorkflowCreateWorkflowPreparationJobsConnector"]


class CreateWorkflowCreateWorkflowPreparationJobsConnector(BaseModel):
    type: FilePreparationServiceTypes
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    azure_document: Optional[
        "CreateWorkflowCreateWorkflowPreparationJobsConnectorAzureDocument"
    ] = Field(alias="azureDocument")
    deepgram: Optional["CreateWorkflowCreateWorkflowPreparationJobsConnectorDeepgram"]
    assembly_ai: Optional[
        "CreateWorkflowCreateWorkflowPreparationJobsConnectorAssemblyAi"
    ] = Field(alias="assemblyAI")
    page: Optional["CreateWorkflowCreateWorkflowPreparationJobsConnectorPage"]
    document: Optional["CreateWorkflowCreateWorkflowPreparationJobsConnectorDocument"]
    email: Optional["CreateWorkflowCreateWorkflowPreparationJobsConnectorEmail"]
    model_document: Optional[
        "CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocument"
    ] = Field(alias="modelDocument")
    reducto: Optional["CreateWorkflowCreateWorkflowPreparationJobsConnectorReducto"]
    mistral: Optional["CreateWorkflowCreateWorkflowPreparationJobsConnectorMistral"]


class CreateWorkflowCreateWorkflowPreparationJobsConnectorAzureDocument(BaseModel):
    version: Optional[AzureDocumentIntelligenceVersions]
    model: Optional[AzureDocumentIntelligenceModels]
    endpoint: Optional[Any]
    key: Optional[str]


class CreateWorkflowCreateWorkflowPreparationJobsConnectorDeepgram(BaseModel):
    model: Optional[DeepgramModels]
    key: Optional[str]
    enable_redaction: Optional[bool] = Field(alias="enableRedaction")
    enable_speaker_diarization: Optional[bool] = Field(alias="enableSpeakerDiarization")
    detect_language: Optional[bool] = Field(alias="detectLanguage")
    language: Optional[str]


class CreateWorkflowCreateWorkflowPreparationJobsConnectorAssemblyAi(BaseModel):
    model: Optional[AssemblyAIModels]
    key: Optional[str]
    enable_redaction: Optional[bool] = Field(alias="enableRedaction")
    enable_speaker_diarization: Optional[bool] = Field(alias="enableSpeakerDiarization")
    detect_language: Optional[bool] = Field(alias="detectLanguage")
    language: Optional[str]


class CreateWorkflowCreateWorkflowPreparationJobsConnectorPage(BaseModel):
    enable_screenshot: Optional[bool] = Field(alias="enableScreenshot")


class CreateWorkflowCreateWorkflowPreparationJobsConnectorDocument(BaseModel):
    include_images: Optional[bool] = Field(alias="includeImages")


class CreateWorkflowCreateWorkflowPreparationJobsConnectorEmail(BaseModel):
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocument(BaseModel):
    specification: Optional[
        "CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocumentSpecification"
    ]


class CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocumentSpecification(
    BaseModel
):
    id: str


class CreateWorkflowCreateWorkflowPreparationJobsConnectorReducto(BaseModel):
    ocr_mode: Optional[ReductoOcrModes] = Field(alias="ocrMode")
    ocr_system: Optional[ReductoOcrSystems] = Field(alias="ocrSystem")
    extraction_mode: Optional[ReductoExtractionModes] = Field(alias="extractionMode")
    enable_enrichment: Optional[bool] = Field(alias="enableEnrichment")
    enrichment_mode: Optional[ReductoEnrichmentModes] = Field(alias="enrichmentMode")
    key: Optional[str]


class CreateWorkflowCreateWorkflowPreparationJobsConnectorMistral(BaseModel):
    key: Optional[str]


class CreateWorkflowCreateWorkflowExtraction(BaseModel):
    jobs: Optional[List[Optional["CreateWorkflowCreateWorkflowExtractionJobs"]]]


class CreateWorkflowCreateWorkflowExtractionJobs(BaseModel):
    connector: Optional["CreateWorkflowCreateWorkflowExtractionJobsConnector"]


class CreateWorkflowCreateWorkflowExtractionJobsConnector(BaseModel):
    type: EntityExtractionServiceTypes
    content_types: Optional[List[ContentTypes]] = Field(alias="contentTypes")
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    extracted_types: Optional[List[ObservableTypes]] = Field(alias="extractedTypes")
    extracted_count: Optional[int] = Field(alias="extractedCount")
    azure_text: Optional[
        "CreateWorkflowCreateWorkflowExtractionJobsConnectorAzureText"
    ] = Field(alias="azureText")
    azure_image: Optional[
        "CreateWorkflowCreateWorkflowExtractionJobsConnectorAzureImage"
    ] = Field(alias="azureImage")
    model_image: Optional[
        "CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImage"
    ] = Field(alias="modelImage")
    model_text: Optional[
        "CreateWorkflowCreateWorkflowExtractionJobsConnectorModelText"
    ] = Field(alias="modelText")


class CreateWorkflowCreateWorkflowExtractionJobsConnectorAzureText(BaseModel):
    confidence_threshold: Optional[float] = Field(alias="confidenceThreshold")
    enable_pii: Optional[bool] = Field(alias="enablePII")


class CreateWorkflowCreateWorkflowExtractionJobsConnectorAzureImage(BaseModel):
    confidence_threshold: Optional[float] = Field(alias="confidenceThreshold")


class CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImage(BaseModel):
    specification: Optional[
        "CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImageSpecification"
    ]


class CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImageSpecification(
    BaseModel
):
    id: str


class CreateWorkflowCreateWorkflowExtractionJobsConnectorModelText(BaseModel):
    specification: Optional[
        "CreateWorkflowCreateWorkflowExtractionJobsConnectorModelTextSpecification"
    ]


class CreateWorkflowCreateWorkflowExtractionJobsConnectorModelTextSpecification(
    BaseModel
):
    id: str


class CreateWorkflowCreateWorkflowClassification(BaseModel):
    jobs: Optional[List[Optional["CreateWorkflowCreateWorkflowClassificationJobs"]]]


class CreateWorkflowCreateWorkflowClassificationJobs(BaseModel):
    connector: Optional["CreateWorkflowCreateWorkflowClassificationJobsConnector"]


class CreateWorkflowCreateWorkflowClassificationJobsConnector(BaseModel):
    type: ContentClassificationServiceTypes
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")
    model: Optional["CreateWorkflowCreateWorkflowClassificationJobsConnectorModel"]
    regex: Optional["CreateWorkflowCreateWorkflowClassificationJobsConnectorRegex"]


class CreateWorkflowCreateWorkflowClassificationJobsConnectorModel(BaseModel):
    specification: Optional[
        "CreateWorkflowCreateWorkflowClassificationJobsConnectorModelSpecification"
    ]
    rules: Optional[
        List[
            Optional[
                "CreateWorkflowCreateWorkflowClassificationJobsConnectorModelRules"
            ]
        ]
    ]


class CreateWorkflowCreateWorkflowClassificationJobsConnectorModelSpecification(
    BaseModel
):
    id: str


class CreateWorkflowCreateWorkflowClassificationJobsConnectorModelRules(BaseModel):
    then: Optional[str]
    if_: Optional[str] = Field(alias="if")


class CreateWorkflowCreateWorkflowClassificationJobsConnectorRegex(BaseModel):
    rules: Optional[
        List[
            Optional[
                "CreateWorkflowCreateWorkflowClassificationJobsConnectorRegexRules"
            ]
        ]
    ]


class CreateWorkflowCreateWorkflowClassificationJobsConnectorRegexRules(BaseModel):
    then: Optional[str]
    type: Optional[RegexSourceTypes]
    path: Optional[str]
    matches: Optional[str]


class CreateWorkflowCreateWorkflowEnrichment(BaseModel):
    link: Optional["CreateWorkflowCreateWorkflowEnrichmentLink"]
    jobs: Optional[List[Optional["CreateWorkflowCreateWorkflowEnrichmentJobs"]]]


class CreateWorkflowCreateWorkflowEnrichmentLink(BaseModel):
    enable_crawling: Optional[bool] = Field(alias="enableCrawling")
    allowed_domains: Optional[List[str]] = Field(alias="allowedDomains")
    excluded_domains: Optional[List[str]] = Field(alias="excludedDomains")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")
    allowed_links: Optional[List[LinkTypes]] = Field(alias="allowedLinks")
    excluded_links: Optional[List[LinkTypes]] = Field(alias="excludedLinks")
    allowed_files: Optional[List[FileTypes]] = Field(alias="allowedFiles")
    excluded_files: Optional[List[FileTypes]] = Field(alias="excludedFiles")
    allowed_content_types: Optional[List[ContentTypes]] = Field(
        alias="allowedContentTypes"
    )
    excluded_content_types: Optional[List[ContentTypes]] = Field(
        alias="excludedContentTypes"
    )
    allow_content_domain: Optional[bool] = Field(alias="allowContentDomain")
    maximum_links: Optional[int] = Field(alias="maximumLinks")


class CreateWorkflowCreateWorkflowEnrichmentJobs(BaseModel):
    connector: Optional["CreateWorkflowCreateWorkflowEnrichmentJobsConnector"]


class CreateWorkflowCreateWorkflowEnrichmentJobsConnector(BaseModel):
    type: Optional[EntityEnrichmentServiceTypes]
    enriched_types: Optional[List[Optional[ObservableTypes]]] = Field(
        alias="enrichedTypes"
    )
    fhir: Optional["CreateWorkflowCreateWorkflowEnrichmentJobsConnectorFhir"]
    diffbot: Optional["CreateWorkflowCreateWorkflowEnrichmentJobsConnectorDiffbot"]


class CreateWorkflowCreateWorkflowEnrichmentJobsConnectorFhir(BaseModel):
    endpoint: Optional[Any]


class CreateWorkflowCreateWorkflowEnrichmentJobsConnectorDiffbot(BaseModel):
    key: Optional[Any]


class CreateWorkflowCreateWorkflowStorage(BaseModel):
    policy: Optional["CreateWorkflowCreateWorkflowStoragePolicy"]


class CreateWorkflowCreateWorkflowStoragePolicy(BaseModel):
    type: Optional[StoragePolicyTypes]
    allow_duplicates: Optional[bool] = Field(alias="allowDuplicates")


class CreateWorkflowCreateWorkflowActions(BaseModel):
    connector: Optional["CreateWorkflowCreateWorkflowActionsConnector"]


class CreateWorkflowCreateWorkflowActionsConnector(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["CreateWorkflowCreateWorkflowActionsConnectorSlack"]
    email: Optional["CreateWorkflowCreateWorkflowActionsConnectorEmail"]
    twitter: Optional["CreateWorkflowCreateWorkflowActionsConnectorTwitter"]
    mcp: Optional["CreateWorkflowCreateWorkflowActionsConnectorMcp"]


class CreateWorkflowCreateWorkflowActionsConnectorSlack(BaseModel):
    token: str
    channel: str


class CreateWorkflowCreateWorkflowActionsConnectorEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class CreateWorkflowCreateWorkflowActionsConnectorTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


class CreateWorkflowCreateWorkflowActionsConnectorMcp(BaseModel):
    token: Optional[str]
    type: MCPServerTypes


CreateWorkflow.model_rebuild()
CreateWorkflowCreateWorkflow.model_rebuild()
CreateWorkflowCreateWorkflowIngestion.model_rebuild()
CreateWorkflowCreateWorkflowIngestionObservations.model_rebuild()
CreateWorkflowCreateWorkflowIndexing.model_rebuild()
CreateWorkflowCreateWorkflowIndexingJobs.model_rebuild()
CreateWorkflowCreateWorkflowPreparation.model_rebuild()
CreateWorkflowCreateWorkflowPreparationSummarizations.model_rebuild()
CreateWorkflowCreateWorkflowPreparationJobs.model_rebuild()
CreateWorkflowCreateWorkflowPreparationJobsConnector.model_rebuild()
CreateWorkflowCreateWorkflowPreparationJobsConnectorModelDocument.model_rebuild()
CreateWorkflowCreateWorkflowExtraction.model_rebuild()
CreateWorkflowCreateWorkflowExtractionJobs.model_rebuild()
CreateWorkflowCreateWorkflowExtractionJobsConnector.model_rebuild()
CreateWorkflowCreateWorkflowExtractionJobsConnectorModelImage.model_rebuild()
CreateWorkflowCreateWorkflowExtractionJobsConnectorModelText.model_rebuild()
CreateWorkflowCreateWorkflowClassification.model_rebuild()
CreateWorkflowCreateWorkflowClassificationJobs.model_rebuild()
CreateWorkflowCreateWorkflowClassificationJobsConnector.model_rebuild()
CreateWorkflowCreateWorkflowClassificationJobsConnectorModel.model_rebuild()
CreateWorkflowCreateWorkflowClassificationJobsConnectorRegex.model_rebuild()
CreateWorkflowCreateWorkflowEnrichment.model_rebuild()
CreateWorkflowCreateWorkflowEnrichmentJobs.model_rebuild()
CreateWorkflowCreateWorkflowEnrichmentJobsConnector.model_rebuild()
CreateWorkflowCreateWorkflowStorage.model_rebuild()
CreateWorkflowCreateWorkflowActions.model_rebuild()
CreateWorkflowCreateWorkflowActionsConnector.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountUsers(BaseModel):
    count_users: Optional["CountUsersCountUsers"] = Field(alias="countUsers")


class CountUsersCountUsers(BaseModel):
    count: Optional[Any]


CountUsers.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteOrganization(BaseModel):
    delete_organization: Optional["DeleteOrganizationDeleteOrganization"] = Field(
        alias="deleteOrganization"
    )


class DeleteOrganizationDeleteOrganization(BaseModel):
    id: str
    state: EntityState


DeleteOrganization.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentTypes, EntityState, FileTypes, ObservableTypes, ViewTypes


class GetView(BaseModel):
    view: Optional["GetViewView"]


class GetViewView(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "GetViewViewOwner"
    state: EntityState
    type: Optional[ViewTypes]
    filter: Optional["GetViewViewFilter"]
    augmented_filter: Optional["GetViewViewAugmentedFilter"] = Field(
        alias="augmentedFilter"
    )


class GetViewViewOwner(BaseModel):
    id: str


class GetViewViewFilter(BaseModel):
    date_range: Optional["GetViewViewFilterDateRange"] = Field(alias="dateRange")
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional["GetViewViewFilterCreationDateRange"] = Field(
        alias="creationDateRange"
    )
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["GetViewViewFilterFileSizeRange"] = Field(
        alias="fileSizeRange"
    )
    similar_contents: Optional[List["GetViewViewFilterSimilarContents"]] = Field(
        alias="similarContents"
    )
    contents: Optional[List["GetViewViewFilterContents"]]
    feeds: Optional[List["GetViewViewFilterFeeds"]]
    workflows: Optional[List["GetViewViewFilterWorkflows"]]
    collections: Optional[List["GetViewViewFilterCollections"]]
    users: Optional[List["GetViewViewFilterUsers"]]
    observations: Optional[List["GetViewViewFilterObservations"]]
    or_: Optional[List["GetViewViewFilterOr"]] = Field(alias="or")
    and_: Optional[List["GetViewViewFilterAnd"]] = Field(alias="and")


class GetViewViewFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetViewViewFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetViewViewFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetViewViewFilterSimilarContents(BaseModel):
    id: str


class GetViewViewFilterContents(BaseModel):
    id: str


class GetViewViewFilterFeeds(BaseModel):
    id: str


class GetViewViewFilterWorkflows(BaseModel):
    id: str


class GetViewViewFilterCollections(BaseModel):
    id: str


class GetViewViewFilterUsers(BaseModel):
    id: str


class GetViewViewFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "GetViewViewFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetViewViewFilterObservationsObservable(BaseModel):
    id: str


class GetViewViewFilterOr(BaseModel):
    feeds: Optional[List["GetViewViewFilterOrFeeds"]]
    workflows: Optional[List["GetViewViewFilterOrWorkflows"]]
    collections: Optional[List["GetViewViewFilterOrCollections"]]
    users: Optional[List["GetViewViewFilterOrUsers"]]
    observations: Optional[List["GetViewViewFilterOrObservations"]]


class GetViewViewFilterOrFeeds(BaseModel):
    id: str


class GetViewViewFilterOrWorkflows(BaseModel):
    id: str


class GetViewViewFilterOrCollections(BaseModel):
    id: str


class GetViewViewFilterOrUsers(BaseModel):
    id: str


class GetViewViewFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "GetViewViewFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetViewViewFilterOrObservationsObservable(BaseModel):
    id: str


class GetViewViewFilterAnd(BaseModel):
    feeds: Optional[List["GetViewViewFilterAndFeeds"]]
    workflows: Optional[List["GetViewViewFilterAndWorkflows"]]
    collections: Optional[List["GetViewViewFilterAndCollections"]]
    users: Optional[List["GetViewViewFilterAndUsers"]]
    observations: Optional[List["GetViewViewFilterAndObservations"]]


class GetViewViewFilterAndFeeds(BaseModel):
    id: str


class GetViewViewFilterAndWorkflows(BaseModel):
    id: str


class GetViewViewFilterAndCollections(BaseModel):
    id: str


class GetViewViewFilterAndUsers(BaseModel):
    id: str


class GetViewViewFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "GetViewViewFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetViewViewFilterAndObservationsObservable(BaseModel):
    id: str


class GetViewViewAugmentedFilter(BaseModel):
    date_range: Optional["GetViewViewAugmentedFilterDateRange"] = Field(
        alias="dateRange"
    )
    in_last: Optional[Any] = Field(alias="inLast")
    creation_date_range: Optional["GetViewViewAugmentedFilterCreationDateRange"] = (
        Field(alias="creationDateRange")
    )
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[Optional[FileTypes]]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    file_size_range: Optional["GetViewViewAugmentedFilterFileSizeRange"] = Field(
        alias="fileSizeRange"
    )
    similar_contents: Optional[List["GetViewViewAugmentedFilterSimilarContents"]] = (
        Field(alias="similarContents")
    )
    contents: Optional[List["GetViewViewAugmentedFilterContents"]]
    feeds: Optional[List["GetViewViewAugmentedFilterFeeds"]]
    workflows: Optional[List["GetViewViewAugmentedFilterWorkflows"]]
    collections: Optional[List["GetViewViewAugmentedFilterCollections"]]
    users: Optional[List["GetViewViewAugmentedFilterUsers"]]
    observations: Optional[List["GetViewViewAugmentedFilterObservations"]]
    or_: Optional[List["GetViewViewAugmentedFilterOr"]] = Field(alias="or")
    and_: Optional[List["GetViewViewAugmentedFilterAnd"]] = Field(alias="and")


class GetViewViewAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetViewViewAugmentedFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetViewViewAugmentedFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class GetViewViewAugmentedFilterSimilarContents(BaseModel):
    id: str


class GetViewViewAugmentedFilterContents(BaseModel):
    id: str


class GetViewViewAugmentedFilterFeeds(BaseModel):
    id: str


class GetViewViewAugmentedFilterWorkflows(BaseModel):
    id: str


class GetViewViewAugmentedFilterCollections(BaseModel):
    id: str


class GetViewViewAugmentedFilterUsers(BaseModel):
    id: str


class GetViewViewAugmentedFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "GetViewViewAugmentedFilterObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetViewViewAugmentedFilterObservationsObservable(BaseModel):
    id: str


class GetViewViewAugmentedFilterOr(BaseModel):
    feeds: Optional[List["GetViewViewAugmentedFilterOrFeeds"]]
    workflows: Optional[List["GetViewViewAugmentedFilterOrWorkflows"]]
    collections: Optional[List["GetViewViewAugmentedFilterOrCollections"]]
    users: Optional[List["GetViewViewAugmentedFilterOrUsers"]]
    observations: Optional[List["GetViewViewAugmentedFilterOrObservations"]]


class GetViewViewAugmentedFilterOrFeeds(BaseModel):
    id: str


class GetViewViewAugmentedFilterOrWorkflows(BaseModel):
    id: str


class GetViewViewAugmentedFilterOrCollections(BaseModel):
    id: str


class GetViewViewAugmentedFilterOrUsers(BaseModel):
    id: str


class GetViewViewAugmentedFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "GetViewViewAugmentedFilterOrObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetViewViewAugmentedFilterOrObservationsObservable(BaseModel):
    id: str


class GetViewViewAugmentedFilterAnd(BaseModel):
    feeds: Optional[List["GetViewViewAugmentedFilterAndFeeds"]]
    workflows: Optional[List["GetViewViewAugmentedFilterAndWorkflows"]]
    collections: Optional[List["GetViewViewAugmentedFilterAndCollections"]]
    users: Optional[List["GetViewViewAugmentedFilterAndUsers"]]
    observations: Optional[List["GetViewViewAugmentedFilterAndObservations"]]


class GetViewViewAugmentedFilterAndFeeds(BaseModel):
    id: str


class GetViewViewAugmentedFilterAndWorkflows(BaseModel):
    id: str


class GetViewViewAugmentedFilterAndCollections(BaseModel):
    id: str


class GetViewViewAugmentedFilterAndUsers(BaseModel):
    id: str


class GetViewViewAugmentedFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "GetViewViewAugmentedFilterAndObservationsObservable"
    states: Optional[List[Optional[EntityState]]]


class GetViewViewAugmentedFilterAndObservationsObservable(BaseModel):
    id: str


GetView.model_rebuild()
GetViewView.model_rebuild()
GetViewViewFilter.model_rebuild()
GetViewViewFilterObservations.model_rebuild()
GetViewViewFilterOr.model_rebuild()
GetViewViewFilterOrObservations.model_rebuild()
GetViewViewFilterAnd.model_rebuild()
GetViewViewFilterAndObservations.model_rebuild()
GetViewViewAugmentedFilter.model_rebuild()
GetViewViewAugmentedFilterObservations.model_rebuild()
GetViewViewAugmentedFilterOr.model_rebuild()
GetViewViewAugmentedFilterOrObservations.model_rebuild()
GetViewViewAugmentedFilterAnd.model_rebuild()
GetViewViewAugmentedFilterAndObservations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpsertLabel(BaseModel):
    upsert_label: Optional["UpsertLabelUpsertLabel"] = Field(alias="upsertLabel")


class UpsertLabelUpsertLabel(BaseModel):
    id: str
    name: str


UpsertLabel.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountViews(BaseModel):
    count_views: Optional["CountViewsCountViews"] = Field(alias="countViews")


class CountViewsCountViews(BaseModel):
    count: Optional[Any]


CountViews.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAlert(BaseModel):
    delete_alert: Optional["DeleteAlertDeleteAlert"] = Field(alias="deleteAlert")


class DeleteAlertDeleteAlert(BaseModel):
    id: str
    state: EntityState


DeleteAlert.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AssemblyAIModels,
    AzureDocumentIntelligenceModels,
    AzureDocumentIntelligenceVersions,
    ContentClassificationServiceTypes,
    ContentIndexingServiceTypes,
    ContentTypes,
    DeepgramModels,
    EntityEnrichmentServiceTypes,
    EntityExtractionServiceTypes,
    EntityState,
    FilePreparationServiceTypes,
    FileTypes,
    IntegrationServiceTypes,
    LinkTypes,
    MCPServerTypes,
    ObservableTypes,
    ReductoEnrichmentModes,
    ReductoExtractionModes,
    ReductoOcrModes,
    ReductoOcrSystems,
    RegexSourceTypes,
    StoragePolicyTypes,
    SummarizationTypes,
)


class GetWorkflow(BaseModel):
    workflow: Optional["GetWorkflowWorkflow"]


class GetWorkflowWorkflow(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    relevance: Optional[float]
    owner: "GetWorkflowWorkflowOwner"
    state: EntityState
    ingestion: Optional["GetWorkflowWorkflowIngestion"]
    indexing: Optional["GetWorkflowWorkflowIndexing"]
    preparation: Optional["GetWorkflowWorkflowPreparation"]
    extraction: Optional["GetWorkflowWorkflowExtraction"]
    classification: Optional["GetWorkflowWorkflowClassification"]
    enrichment: Optional["GetWorkflowWorkflowEnrichment"]
    storage: Optional["GetWorkflowWorkflowStorage"]
    actions: Optional[List[Optional["GetWorkflowWorkflowActions"]]]


class GetWorkflowWorkflowOwner(BaseModel):
    id: str


class GetWorkflowWorkflowIngestion(BaseModel):
    if_: Optional["GetWorkflowWorkflowIngestionIf"] = Field(alias="if")
    collections: Optional[List[Optional["GetWorkflowWorkflowIngestionCollections"]]]
    observations: Optional[List[Optional["GetWorkflowWorkflowIngestionObservations"]]]
    enable_email_collections: Optional[bool] = Field(alias="enableEmailCollections")


class GetWorkflowWorkflowIngestionIf(BaseModel):
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")


class GetWorkflowWorkflowIngestionCollections(BaseModel):
    id: str


class GetWorkflowWorkflowIngestionObservations(BaseModel):
    type: ObservableTypes
    observable: "GetWorkflowWorkflowIngestionObservationsObservable"


class GetWorkflowWorkflowIngestionObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class GetWorkflowWorkflowIndexing(BaseModel):
    jobs: Optional[List[Optional["GetWorkflowWorkflowIndexingJobs"]]]


class GetWorkflowWorkflowIndexingJobs(BaseModel):
    connector: Optional["GetWorkflowWorkflowIndexingJobsConnector"]


class GetWorkflowWorkflowIndexingJobsConnector(BaseModel):
    type: Optional[ContentIndexingServiceTypes]
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")


class GetWorkflowWorkflowPreparation(BaseModel):
    enable_unblocked_capture: Optional[bool] = Field(alias="enableUnblockedCapture")
    disable_smart_capture: Optional[bool] = Field(alias="disableSmartCapture")
    summarizations: Optional[
        List[Optional["GetWorkflowWorkflowPreparationSummarizations"]]
    ]
    jobs: Optional[List[Optional["GetWorkflowWorkflowPreparationJobs"]]]


class GetWorkflowWorkflowPreparationSummarizations(BaseModel):
    type: SummarizationTypes
    specification: Optional["GetWorkflowWorkflowPreparationSummarizationsSpecification"]
    tokens: Optional[int]
    items: Optional[int]
    prompt: Optional[str]


class GetWorkflowWorkflowPreparationSummarizationsSpecification(BaseModel):
    id: str


class GetWorkflowWorkflowPreparationJobs(BaseModel):
    connector: Optional["GetWorkflowWorkflowPreparationJobsConnector"]


class GetWorkflowWorkflowPreparationJobsConnector(BaseModel):
    type: FilePreparationServiceTypes
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    azure_document: Optional[
        "GetWorkflowWorkflowPreparationJobsConnectorAzureDocument"
    ] = Field(alias="azureDocument")
    deepgram: Optional["GetWorkflowWorkflowPreparationJobsConnectorDeepgram"]
    assembly_ai: Optional["GetWorkflowWorkflowPreparationJobsConnectorAssemblyAi"] = (
        Field(alias="assemblyAI")
    )
    page: Optional["GetWorkflowWorkflowPreparationJobsConnectorPage"]
    document: Optional["GetWorkflowWorkflowPreparationJobsConnectorDocument"]
    email: Optional["GetWorkflowWorkflowPreparationJobsConnectorEmail"]
    model_document: Optional[
        "GetWorkflowWorkflowPreparationJobsConnectorModelDocument"
    ] = Field(alias="modelDocument")
    reducto: Optional["GetWorkflowWorkflowPreparationJobsConnectorReducto"]
    mistral: Optional["GetWorkflowWorkflowPreparationJobsConnectorMistral"]


class GetWorkflowWorkflowPreparationJobsConnectorAzureDocument(BaseModel):
    version: Optional[AzureDocumentIntelligenceVersions]
    model: Optional[AzureDocumentIntelligenceModels]
    endpoint: Optional[Any]
    key: Optional[str]


class GetWorkflowWorkflowPreparationJobsConnectorDeepgram(BaseModel):
    model: Optional[DeepgramModels]
    key: Optional[str]
    enable_redaction: Optional[bool] = Field(alias="enableRedaction")
    enable_speaker_diarization: Optional[bool] = Field(alias="enableSpeakerDiarization")
    detect_language: Optional[bool] = Field(alias="detectLanguage")
    language: Optional[str]


class GetWorkflowWorkflowPreparationJobsConnectorAssemblyAi(BaseModel):
    model: Optional[AssemblyAIModels]
    key: Optional[str]
    enable_redaction: Optional[bool] = Field(alias="enableRedaction")
    enable_speaker_diarization: Optional[bool] = Field(alias="enableSpeakerDiarization")
    detect_language: Optional[bool] = Field(alias="detectLanguage")
    language: Optional[str]


class GetWorkflowWorkflowPreparationJobsConnectorPage(BaseModel):
    enable_screenshot: Optional[bool] = Field(alias="enableScreenshot")


class GetWorkflowWorkflowPreparationJobsConnectorDocument(BaseModel):
    include_images: Optional[bool] = Field(alias="includeImages")


class GetWorkflowWorkflowPreparationJobsConnectorEmail(BaseModel):
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetWorkflowWorkflowPreparationJobsConnectorModelDocument(BaseModel):
    specification: Optional[
        "GetWorkflowWorkflowPreparationJobsConnectorModelDocumentSpecification"
    ]


class GetWorkflowWorkflowPreparationJobsConnectorModelDocumentSpecification(BaseModel):
    id: str


class GetWorkflowWorkflowPreparationJobsConnectorReducto(BaseModel):
    ocr_mode: Optional[ReductoOcrModes] = Field(alias="ocrMode")
    ocr_system: Optional[ReductoOcrSystems] = Field(alias="ocrSystem")
    extraction_mode: Optional[ReductoExtractionModes] = Field(alias="extractionMode")
    enable_enrichment: Optional[bool] = Field(alias="enableEnrichment")
    enrichment_mode: Optional[ReductoEnrichmentModes] = Field(alias="enrichmentMode")
    key: Optional[str]


class GetWorkflowWorkflowPreparationJobsConnectorMistral(BaseModel):
    key: Optional[str]


class GetWorkflowWorkflowExtraction(BaseModel):
    jobs: Optional[List[Optional["GetWorkflowWorkflowExtractionJobs"]]]


class GetWorkflowWorkflowExtractionJobs(BaseModel):
    connector: Optional["GetWorkflowWorkflowExtractionJobsConnector"]


class GetWorkflowWorkflowExtractionJobsConnector(BaseModel):
    type: EntityExtractionServiceTypes
    content_types: Optional[List[ContentTypes]] = Field(alias="contentTypes")
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    extracted_types: Optional[List[ObservableTypes]] = Field(alias="extractedTypes")
    extracted_count: Optional[int] = Field(alias="extractedCount")
    azure_text: Optional["GetWorkflowWorkflowExtractionJobsConnectorAzureText"] = Field(
        alias="azureText"
    )
    azure_image: Optional["GetWorkflowWorkflowExtractionJobsConnectorAzureImage"] = (
        Field(alias="azureImage")
    )
    model_image: Optional["GetWorkflowWorkflowExtractionJobsConnectorModelImage"] = (
        Field(alias="modelImage")
    )
    model_text: Optional["GetWorkflowWorkflowExtractionJobsConnectorModelText"] = Field(
        alias="modelText"
    )


class GetWorkflowWorkflowExtractionJobsConnectorAzureText(BaseModel):
    confidence_threshold: Optional[float] = Field(alias="confidenceThreshold")
    enable_pii: Optional[bool] = Field(alias="enablePII")


class GetWorkflowWorkflowExtractionJobsConnectorAzureImage(BaseModel):
    confidence_threshold: Optional[float] = Field(alias="confidenceThreshold")


class GetWorkflowWorkflowExtractionJobsConnectorModelImage(BaseModel):
    specification: Optional[
        "GetWorkflowWorkflowExtractionJobsConnectorModelImageSpecification"
    ]


class GetWorkflowWorkflowExtractionJobsConnectorModelImageSpecification(BaseModel):
    id: str


class GetWorkflowWorkflowExtractionJobsConnectorModelText(BaseModel):
    specification: Optional[
        "GetWorkflowWorkflowExtractionJobsConnectorModelTextSpecification"
    ]


class GetWorkflowWorkflowExtractionJobsConnectorModelTextSpecification(BaseModel):
    id: str


class GetWorkflowWorkflowClassification(BaseModel):
    jobs: Optional[List[Optional["GetWorkflowWorkflowClassificationJobs"]]]


class GetWorkflowWorkflowClassificationJobs(BaseModel):
    connector: Optional["GetWorkflowWorkflowClassificationJobsConnector"]


class GetWorkflowWorkflowClassificationJobsConnector(BaseModel):
    type: ContentClassificationServiceTypes
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")
    model: Optional["GetWorkflowWorkflowClassificationJobsConnectorModel"]
    regex: Optional["GetWorkflowWorkflowClassificationJobsConnectorRegex"]


class GetWorkflowWorkflowClassificationJobsConnectorModel(BaseModel):
    specification: Optional[
        "GetWorkflowWorkflowClassificationJobsConnectorModelSpecification"
    ]
    rules: Optional[
        List[Optional["GetWorkflowWorkflowClassificationJobsConnectorModelRules"]]
    ]


class GetWorkflowWorkflowClassificationJobsConnectorModelSpecification(BaseModel):
    id: str


class GetWorkflowWorkflowClassificationJobsConnectorModelRules(BaseModel):
    then: Optional[str]
    if_: Optional[str] = Field(alias="if")


class GetWorkflowWorkflowClassificationJobsConnectorRegex(BaseModel):
    rules: Optional[
        List[Optional["GetWorkflowWorkflowClassificationJobsConnectorRegexRules"]]
    ]


class GetWorkflowWorkflowClassificationJobsConnectorRegexRules(BaseModel):
    then: Optional[str]
    type: Optional[RegexSourceTypes]
    path: Optional[str]
    matches: Optional[str]


class GetWorkflowWorkflowEnrichment(BaseModel):
    link: Optional["GetWorkflowWorkflowEnrichmentLink"]
    jobs: Optional[List[Optional["GetWorkflowWorkflowEnrichmentJobs"]]]


class GetWorkflowWorkflowEnrichmentLink(BaseModel):
    enable_crawling: Optional[bool] = Field(alias="enableCrawling")
    allowed_domains: Optional[List[str]] = Field(alias="allowedDomains")
    excluded_domains: Optional[List[str]] = Field(alias="excludedDomains")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")
    allowed_links: Optional[List[LinkTypes]] = Field(alias="allowedLinks")
    excluded_links: Optional[List[LinkTypes]] = Field(alias="excludedLinks")
    allowed_files: Optional[List[FileTypes]] = Field(alias="allowedFiles")
    excluded_files: Optional[List[FileTypes]] = Field(alias="excludedFiles")
    allowed_content_types: Optional[List[ContentTypes]] = Field(
        alias="allowedContentTypes"
    )
    excluded_content_types: Optional[List[ContentTypes]] = Field(
        alias="excludedContentTypes"
    )
    allow_content_domain: Optional[bool] = Field(alias="allowContentDomain")
    maximum_links: Optional[int] = Field(alias="maximumLinks")


class GetWorkflowWorkflowEnrichmentJobs(BaseModel):
    connector: Optional["GetWorkflowWorkflowEnrichmentJobsConnector"]


class GetWorkflowWorkflowEnrichmentJobsConnector(BaseModel):
    type: Optional[EntityEnrichmentServiceTypes]
    enriched_types: Optional[List[Optional[ObservableTypes]]] = Field(
        alias="enrichedTypes"
    )
    fhir: Optional["GetWorkflowWorkflowEnrichmentJobsConnectorFhir"]
    diffbot: Optional["GetWorkflowWorkflowEnrichmentJobsConnectorDiffbot"]


class GetWorkflowWorkflowEnrichmentJobsConnectorFhir(BaseModel):
    endpoint: Optional[Any]


class GetWorkflowWorkflowEnrichmentJobsConnectorDiffbot(BaseModel):
    key: Optional[Any]


class GetWorkflowWorkflowStorage(BaseModel):
    policy: Optional["GetWorkflowWorkflowStoragePolicy"]


class GetWorkflowWorkflowStoragePolicy(BaseModel):
    type: Optional[StoragePolicyTypes]
    allow_duplicates: Optional[bool] = Field(alias="allowDuplicates")


class GetWorkflowWorkflowActions(BaseModel):
    connector: Optional["GetWorkflowWorkflowActionsConnector"]


class GetWorkflowWorkflowActionsConnector(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["GetWorkflowWorkflowActionsConnectorSlack"]
    email: Optional["GetWorkflowWorkflowActionsConnectorEmail"]
    twitter: Optional["GetWorkflowWorkflowActionsConnectorTwitter"]
    mcp: Optional["GetWorkflowWorkflowActionsConnectorMcp"]


class GetWorkflowWorkflowActionsConnectorSlack(BaseModel):
    token: str
    channel: str


class GetWorkflowWorkflowActionsConnectorEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class GetWorkflowWorkflowActionsConnectorTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


class GetWorkflowWorkflowActionsConnectorMcp(BaseModel):
    token: Optional[str]
    type: MCPServerTypes


GetWorkflow.model_rebuild()
GetWorkflowWorkflow.model_rebuild()
GetWorkflowWorkflowIngestion.model_rebuild()
GetWorkflowWorkflowIngestionObservations.model_rebuild()
GetWorkflowWorkflowIndexing.model_rebuild()
GetWorkflowWorkflowIndexingJobs.model_rebuild()
GetWorkflowWorkflowPreparation.model_rebuild()
GetWorkflowWorkflowPreparationSummarizations.model_rebuild()
GetWorkflowWorkflowPreparationJobs.model_rebuild()
GetWorkflowWorkflowPreparationJobsConnector.model_rebuild()
GetWorkflowWorkflowPreparationJobsConnectorModelDocument.model_rebuild()
GetWorkflowWorkflowExtraction.model_rebuild()
GetWorkflowWorkflowExtractionJobs.model_rebuild()
GetWorkflowWorkflowExtractionJobsConnector.model_rebuild()
GetWorkflowWorkflowExtractionJobsConnectorModelImage.model_rebuild()
GetWorkflowWorkflowExtractionJobsConnectorModelText.model_rebuild()
GetWorkflowWorkflowClassification.model_rebuild()
GetWorkflowWorkflowClassificationJobs.model_rebuild()
GetWorkflowWorkflowClassificationJobsConnector.model_rebuild()
GetWorkflowWorkflowClassificationJobsConnectorModel.model_rebuild()
GetWorkflowWorkflowClassificationJobsConnectorRegex.model_rebuild()
GetWorkflowWorkflowEnrichment.model_rebuild()
GetWorkflowWorkflowEnrichmentJobs.model_rebuild()
GetWorkflowWorkflowEnrichmentJobsConnector.model_rebuild()
GetWorkflowWorkflowStorage.model_rebuild()
GetWorkflowWorkflowActions.model_rebuild()
GetWorkflowWorkflowActionsConnector.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalDrugClasses(BaseModel):
    count_medical_drug_classes: Optional[
        "CountMedicalDrugClassesCountMedicalDrugClasses"
    ] = Field(alias="countMedicalDrugClasses")


class CountMedicalDrugClassesCountMedicalDrugClasses(BaseModel):
    count: Optional[Any]


CountMedicalDrugClasses.model_rebuild()
